@@ -13,7 +13,7 @@ use Scalar::Util qw(blessed);
 use warnings;
 use Data::Dumper;
 
-our $VERSION = '0.199_03';
+our $VERSION = '0.199_04';
 
 sub new
 {
@@ -249,13 +249,13 @@ sub _make_curie {
   my ($self, $uri) = @_;
   my $curie = $self->{namespacemap}->abbreviate($uri);
   unless (defined($curie)) {
-	 $uri->as_string =~ m!(.*)(\#|/)(.*?)$!;
+	 $uri->value =~ m!(.*)(\#|/)(.*?)$!;
 	 my $trim = $1.$2;
 	 $self->{namespacemap}->guess_and_add($trim);
 	 $curie = $self->{namespacemap}->abbreviate($uri);
   }
   unless (defined($curie)) {
-	 $curie = $uri->as_string;
+	 $curie = $uri->value;
   }
   return $curie;
 }
